@@ -17,6 +17,11 @@ import aws_cdk.aws_s3
 import aws_cdk.core
 import aws_cdk.region_info
 import constructs
-__all__ = []
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-route53-patterns", "1.33.0", __name__[0:-6], "aws-route53-patterns@1.33.0.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
